import {
  AddressAutofillOptions,
  AddressAutofillRetrieveResponse,
  AddressAutofillSuggestion,
  AddressAutofillSuggestionResponse,
  AddressAutofillCore,
  SearchBoxCore,
  SearchBoxOptions,
  SearchBoxRetrieveResponse,
  SearchBoxSuggestion,
  SearchBoxSuggestionResponse,
  SearchSession
} from '@mapbox/search-js-core';
import { useMemo } from 'react';

export type SearchSessionType = SearchSession<
  SearchBoxOptions,
  SearchBoxSuggestion,
  SearchBoxSuggestionResponse,
  SearchBoxRetrieveResponse
>;

export type AddressAutofillSearchSessionType = SearchSession<
  AddressAutofillOptions,
  AddressAutofillSuggestion,
  AddressAutofillSuggestionResponse,
  AddressAutofillRetrieveResponse
>;

function useSearchSession(search: SearchBoxCore): SearchSessionType;
function useSearchSession(
  autofill: AddressAutofillCore
): AddressAutofillSearchSessionType;

/**
 * A React hook that returns a {@link SearchSession} instance.
 *
 * @param {SearchBoxCore | AddressAutofillCore} search
 * @returns {SearchSession}
 * @see {@link SearchSession}
 */
function useSearchSession(
  search: SearchBoxCore | AddressAutofillCore
): SearchSessionType | AddressAutofillSearchSessionType {
  const searchSession = useMemo(() => {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    return new SearchSession(search as any);
  }, [search]);

  if (search instanceof SearchBoxCore) {
    return searchSession as SearchSessionType;
  } else {
    return searchSession as AddressAutofillSearchSessionType;
  }
}

export { useSearchSession };
