import { AddressAutofillCore } from '@mapbox/search-js-core';
import { renderHook, act } from '@testing-library/react-hooks';

import { useAddressAutofillCore } from '../../src/hooks/useAddressAutofillCore';

const ACCESS_TOKEN = 'xyz';

describe('useAddressAutofillCore', () => {
  it('works with access token', () => {
    const { result, rerender } = renderHook(
      ({ accessToken }) => useAddressAutofillCore({ accessToken }),
      { initialProps: { accessToken: ACCESS_TOKEN } }
    );

    expect(result.current).toEqual(expect.any(AddressAutofillCore));
    expect(result.current.accessToken).toEqual(ACCESS_TOKEN);

    act(() => {
      rerender({ accessToken: 'abc' });
    });

    expect(result.current.accessToken).toEqual('abc');
  });

  it('works with options', () => {
    const { result, rerender } = renderHook(
      ({ options }) =>
        useAddressAutofillCore({ accessToken: ACCESS_TOKEN, ...options }),
      { initialProps: { options: {} } }
    );

    expect(result.current).toEqual(expect.any(AddressAutofillCore));
    expect(result.current.defaults).toEqual(AddressAutofillCore.defaults);

    act(() => {
      rerender({ options: { language: 'jp' } });
    });

    expect(result.current.defaults).toEqual({
      ...AddressAutofillCore.defaults,
      language: 'jp'
    });

    // Make sure previous language is "undone".
    act(() => {
      rerender({ options: { proximity: [0, 0] } });
    });

    expect(result.current.defaults).toEqual({
      ...AddressAutofillCore.defaults,
      language: 'en',
      proximity: [0, 0]
    });
  });
});
